@@ -2,7 +2,7 @@ package Bundle::Locale::CLDR::Outlyingoceania;
 
 use version;
 
-our $VERSION = version->declare('v0.34.4');
+our $VERSION = version->declare('v0.45.0');
 
 =head1 NAME
 
@@ -10,8 +10,10 @@ Bundle::Locale::CLDR::Outlyingoceania
 
 =head1 CONTENTS
 
-Locale::CLDR::Locales::En::Any::Dg 0.34.4
-Locale::CLDR::Locales::En::Any::001 0.34.4
+Locale::CLDR::Locales::En::Latn::Dg 0.45.0
+
+Locale::CLDR::Locales::En::Latn::001 0.45.0
+
 
 =cut
 
